Bootstrap按钮 & Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Buttons & Icon Common Buttons & Icons

### Application Buttons

Default +3 编辑 11 Reload
Mailbox 6+
Shop

### Default Buttons Border:

### Button with Icons

### Button Sizing

### Disabled Buttons

### Button Groups

Checkbox:

Radio:

### Button Dropdown

### Lables & Badges

Default Success Warning Danger Info Inverse

1 1 2 4 6 8 3 10 11 2

Large Yellow Purple

Larger Grey Light

Smaller

### Pagination

- 1
- 2
- 3
- 4
- 5

- ← Older
- Newer →

### 361 Scalable FontAwesome Icons (see all icons )

- icon-adjust
- icon-asterisk
- icon-ban-circle
- icon-bar-chart
- icon-barcode
- icon-beaker
- icon-beer
- icon-bell
- icon-bell-alt
- icon-bolt
- icon-book
- icon-bookmark
- icon-bookmark-empty
- icon-briefcase
- icon-bullhorn
- icon-calendar
- icon-camera
- icon-camera-retro
- icon-certificate

- icon-check
- icon-check-empty
- icon-circle
- icon-circle-blank
- icon-cloud
- icon-cloud-download
- icon-cloud-upload
- icon-coffee
- icon-cog
- icon-cogs
- icon-comment
- icon-comment-alt
- icon-comments
- icon-comments-alt
- icon-credit-card
- icon-dashboard
- icon-desktop
- icon-download
- icon-download-alt

- icon-edit
- icon-envelope
- icon-envelope-alt
- icon-exchange
- icon-exclamation-sign
- icon-external-link
- icon-eye-close
- icon-eye-open
- icon-facetime-video
- icon-fighter-jet
- icon-film
- icon-filter
- icon-fire
- icon-flag
- icon-folder-close
- icon-folder-open
- icon-folder-close-alt
- icon-folder-open-alt
- icon-food

- icon-gift
- icon-glass
- icon-globe
- icon-group
- icon-hdd
- icon-headphones
- icon-heart
- icon-heart-empty
- icon-home
- icon-inbox
- icon-info-sign
- icon-key
- icon-leaf
- icon-laptop
- icon-legal
- icon-lemon
- icon-lightbulb
- icon-lock
- icon-unlock

Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container